from setuptools import setup, find_packages

setup(
    name='ValiCoC',
    version='999.99.9',
    description='Validation code filter',
    long_description=open('README.rst').read(),
    author='O_O',
    author_email='Adammiao@outlook.com',
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3"
    ],
    url='https://github.com/Adam-Miao/ValiCoC/'
)
